===================================
Detailed User Interface Information
===================================

Signal
------
Various signal classes in  `PsrSigSim` contain the actual data which is passed
to various other classes to make realistic pulsar signals.

.. automodule:: psrsigsim.signal
    :members:
    :inherited-members:

Pulsar
------

.. automodule:: psrsigsim.pulsar
    :members:
    :inherited-members:

Telescope
---------

.. automodule:: psrsigsim.telescope
    :members:
    :inherited-members:

ISM
---

.. automodule:: psrsigsim.ism
    :members:
    :inherited-members:

IO
--

.. automodule:: psrsigsim.io
    :members:
    :inherited-members:

Simulate
--------

.. automodule:: psrsigsim.simulate
    :members:
    :inherited-members:

Utilities
---------

.. automodule:: psrsigsim.utils
    :members:
    :inherited-members:
